#################################################
# Title: Stealing to remain in office
# Date: December 25th, 2019
# Author: Valentin Figueroa
# Purpose: replicate results in the paper
#################################################

# housekeeping
library(lmtest)
library(sandwich)
rm(list=ls())

###########################################################
# SET THE WORKING DIRECTORY HERE, or save folder in Desktop 
working.directory <- "~/Desktop/replication/"
setwd(working.directory)
###########################################################

# Import dataset
library(readxl)
d <- read_excel("data/stealing_dataset.xlsx")


########################################
# Figure 2: histogram of kickback sizes
########################################

png(file="out/figure2.png")
par(mfrow = c(1,2), mar = c(5,3,2,3))
hist(d$collected_amount,
     xlab = "Daily collection",
     main = "All days (N=1043)",
     col = "pink")
hist(d$collected_amount[d$collection==1],
     xlab = "Kickback sizes",
     main = "Days with kickbacks (N=155)",
     col = "pink")
dev.off()

###########################################
# Figure 3: temporal variation in the data
###########################################

# create indicators for days with elections
elections <- d$date[d$electoral_calendar==0]
elections <- elections[is.na(elections)==FALSE]

png(file="out/figure3.png")
par(mfrow = c(4,1), mar = c(3,5,2,5))
d$delivery2 <- ifelse(d$delivery==1,1,NA)

plot(x = d$date[d$year==2009],
     y = d$collected_amount[d$year==2009],
     type = "l",
     xlab = "Day of the year",
     ylab = "Duffel bags",
     main = "2009",
     ylim = c(0,6))
par(new=TRUE)
plot(x = d$date[d$year==2009],
     y = d$delivery2[d$year==2009],
     xlab = "",
     ylab = "",
     main = "",
     pch = 3,
     axes = FALSE)
abline(v = elections[4], col = "red", lty = 2, lwd = 2)

plot(x = d$date[d$year==2010],
     y = d$collected_amount[d$year==2010],
     type = "l",
     xlab = "Day of the year",
     ylab = "Duffel bags",
     main = "2010",
     ylim = c(0,6))
par(new=TRUE)
plot(x = d$date[d$year==2010],
     y = d$delivery2[d$year==2010],
     xlab = "",
     ylab = "",
     main = "",
     pch = 3,
     axes = FALSE)

plot(x = d$date[d$year==2013],
     y = d$collected_amount[d$year==2013],
     type = "l",
     xlab = "Day of the year",
     ylab = "Duffel bags",
     main = "2013",
     ylim = c(0,6))
par(new=TRUE)
plot(x = d$date[d$year==2013],
     y = d$delivery2[d$year==2013],
     xlab = "",
     ylab = "",
     main = "",
     pch = 3,
     axes = FALSE)
abline(v = elections[2], col = "red", lty = 2, lwd = 2)
abline(v = elections[3], col = "red", lty = 2, lwd = 2)

plot(x = d$date[d$year==2015],
     y = d$collected_amount[d$year==2015],
     type = "l",
     xlab = "Day of the year",
     ylab = "Duffel bags",
     main = "2015",
     ylim = c(0,6))
abline(v = elections[1], col = "red", lty = 2, lwd = 2)
abline(v = d$date[d$year==2015][1], col = "red", lty = 2, lwd = 2)
dev.off()

##################################################
# Appendix: temporal variation at the weekly level
##################################################
library(data.table)

d$week = week(d$date)

week = seq(from = 1,
           to = max(d$week),
           by = 1)

y2009 = c()
y2013 = c()
y2015 = c()


for(i in 1:length(week)){
  y2009[i] = sum(d$collected_amount[d$week==week[i] & d$year==2009])
  y2013[i] = sum(d$collected_amount[d$week==week[i] & d$year==2013])
  y2015[i] = sum(d$collected_amount[d$week==week[i] & d$year==2015])
}
png(file="out/appendix_time_series.png")
par(mfrow = c(3,1))
plot(x = week,
     y = y2009,
     type = "l",
     main = "2009",
     ylab = "Weekly collection",
     xlab = "",
     ylim = c(0,8))
abline(v = 26, col = "red", lty = 2)

plot(x = week,
     y = y2013,
     type = "l",
     main = "2013",
     ylab = "Weekly collection",
     xlab = "",
     ylim = c(0,8))
abline(v = 33, col = "red", lty = 2)
abline(v = 44, col = "red", lty = 2)

plot(x = week,
     y = y2015,
     type = "l",
     main = "2015",
     ylab = "Weekly collection",
     xlab = "",
     ylim = c(0,8))
abline(v = 32, col = "red", lty = 2)
abline(v = 43, col = "red", lty = 2)
dev.off()

################################################
# Figure 4: pre-post political corruption cycle
################################################

# Exclude weekends
d$day <- weekdays(d$date)
d <- d[d$day!="Saturday" & d$day!="Sunday", ]

# set window
window <- 1:37

# create empty matrices to store results
amount <- matrix(ncol = 3, nrow = 37)
collection <- matrix(ncol = 3, nrow = 37)
delivery <- matrix(ncol = 3, nrow = 37)

# compute regression for different windows using a for-loop
for(i in 3:37){
  d2 <- d[abs(d$electoral_calendar)<i, ]
  
  lm1 <- lm(collected_amount ~ pre_post, data = d2)
  
  selm1 <- coeftest(lm1, vcov = vcovHC(lm1, type = "HC1"))[2,2]
  critical.t <- abs(qt(p = 0.05, df = lm1$df.residual))
  
  amount[i,1] <- lm1$coefficients[2] 
  amount[i,2] <- lm1$coefficients[2] + selm1*critical.t
  amount[i,3] <- lm1$coefficients[2] - selm1*critical.t
  
  lm2 <- lm(collection ~ pre_post, data = d2)
  
  selm2 <- coeftest(lm2, vcov = vcovHC(lm2, type = "HC1"))[2,2]
  critical.t <- abs(qt(p = 0.05, df = lm2$df.residual))
  
  collection[i,1] <- lm2$coefficients[2] 
  collection[i,2] <- lm2$coefficients[2] + selm2*critical.t
  collection[i,3] <- lm2$coefficients[2] - selm2*critical.t
  
  lm3 <- lm(delivery ~ pre_post, data = d2)
  
  selm3 <- coeftest(lm3, vcov = vcovHC(lm3, type = "HC1"))[2,2]
  critical.t <- abs(qt(p = 0.05, df = lm3$df.residual))
  
  delivery[i,1] <- lm3$coefficients[2] 
  delivery[i,2] <- lm3$coefficients[2] + selm3*critical.t
  delivery[i,3] <- lm3$coefficients[2] - selm3*critical.t
  
}

# save coefficients for 1, 2, 3 and 4 week window

size7days <- amount[7,1]
collection7days <- collection[7,1]
delivery7days <- delivery[7,1]

size14days <- amount[14,1]
collection14days <- collection[14,1]
delivery14days <- delivery[14,1]

size21days <- amount[21,1]
collection21days <- collection[21,1]
delivery21days <- delivery[21,1]

size28days <- amount[28,1]
collection28days <- collection[28,1]
delivery28days <- delivery[28,1]

# plot the results

png(file="out/figure4.png")
par(mfrow = c(1,3), mar = c(5,3,4,1))

plot(y = amount[,1],
     x = window,
     lwd = 3,
     ylim = c(-0.2,1),
     type = "l",
     main = "Duffel bags collected",
     xlab = "Time window (in days)",
     ylab = "")
par(new = TRUE)
plot(y = amount[,2],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
par(new = TRUE)
plot(y = amount[,3],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
abline(h = 0, col = "red", lty = 2)

plot(y = collection[,1],
     x = window,
     lwd = 3,
     ylim = c(-0.2,1),
     type = "l",
     main = "P(Episode of kickback)",
     xlab = "Time window (in days)",
     ylab = "")
par(new = TRUE)
plot(y = collection[,2],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
par(new = TRUE)
plot(y = collection[,3],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
abline(h = 0, col = "red", lty = 2)

plot(y = delivery[,1],
     x = window,
     type = "l",
     lwd = 3,
     ylim = c(-0.2,1),
     main = "P(Episode of delivery)",
     xlab = "Time window (in days)",
     ylab = "")
par(new = TRUE)
plot(y = delivery[,2],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
par(new = TRUE)
plot(y = delivery[,3],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
abline(h = 0, col = "red", lty = 2)
dev.off()

####################################################
# Figure 5a: pre vs non political corruption cycle
####################################################

# create empty vectors to store results
amount <- matrix(ncol = 3, nrow = 37)
collection <- matrix(ncol = 3, nrow = 37)
delivery <- matrix(ncol = 3, nrow = 37)

for(i in 3:37){
  d2 <- d[abs(d$electoral_calendar)<i | is.na(d$electoral_calendar)==TRUE, ]
  
  lm1 <- lm(collected_amount ~ pre_non, data = d2)
  
  selm1 <- coeftest(lm1, vcov = vcovHC(lm1, type = "HC1"))[2,2]
  critical.t <- abs(qt(p = 0.05, df = lm1$df.residual))
  
  amount[i,1] <- lm1$coefficients[2] 
  amount[i,2] <- lm1$coefficients[2] + selm1*critical.t
  amount[i,3] <- lm1$coefficients[2] - selm1*critical.t
  
  lm2 <- lm(collection ~ pre_non, data = d2)
  
  selm2 <- coeftest(lm2, vcov = vcovHC(lm2, type = "HC1"))[2,2]
  critical.t <- abs(qt(p = 0.05, df = lm2$df.residual))
  
  collection[i,1] <- lm2$coefficients[2] 
  collection[i,2] <- lm2$coefficients[2] + selm2*critical.t
  collection[i,3] <- lm2$coefficients[2] - selm2*critical.t
  
  lm3 <- lm(delivery ~ pre_non, data = d2)
  
  selm3 <- coeftest(lm3, vcov = vcovHC(lm3, type = "HC1"))[2,2]
  critical.t <- abs(qt(p = 0.05, df = lm3$df.residual))
  
  delivery[i,1] <- lm3$coefficients[2] 
  delivery[i,2] <- lm3$coefficients[2] + selm3*critical.t
  delivery[i,3] <- lm3$coefficients[2] - selm3*critical.t
  
}


# make plots

png(file="out/figure5a.png")
par(mfrow = c(1,3), mar = c(5,3,4,1))

plot(y = amount[,1],
     x = window,
     lwd = 3,
     ylim = c(-0.2,1),
     type = "l",
     main = "Duffel bags collected",
     xlab = "Time window (days)",
     ylab = "")
par(new = TRUE)
plot(y = amount[,2],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
par(new = TRUE)
plot(y = amount[,3],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
abline(h = 0, col = "red", lty = 2)

plot(y = collection[,1],
     x = window,
     lwd = 3,
     ylim = c(-0.2,1),
     type = "l",
     main = "P(Episode of kickback)",
     xlab = "Time window (days)",
     ylab = "")
par(new = TRUE)
plot(y = collection[,2],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
par(new = TRUE)
plot(y = collection[,3],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
abline(h = 0, col = "red", lty = 2)

plot(y = delivery[,1],
     x = window,
     type = "l",
     lwd = 3,
     ylim = c(-0.2,1),
     main = "P(Episode of delivery)",
     xlab = "Time window (days)",
     ylab = "")
par(new = TRUE)
plot(y = delivery[,2],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
par(new = TRUE)
plot(y = delivery[,3],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
abline(h = 0, col = "red", lty = 2)
dev.off()

####################################################
# Figure 5b: post vs non political corruption cycle
####################################################

# create empty matrices to store results
amount <- matrix(ncol = 3, nrow = 37)
collection <- matrix(ncol = 3, nrow = 37)
delivery <- matrix(ncol = 3, nrow = 37)

for(i in 3:37){
  d2 <- d[abs(d$electoral_calendar)<i | is.na(d$electoral_calendar)==TRUE, ]
  
  lm1 <- lm(collected_amount ~ post_non, data = d2)
  
  selm1 <- coeftest(lm1, vcov = vcovHC(lm1, type = "HC1"))[2,2]
  critical.t <- abs(qt(p = 0.05, df = lm1$df.residual))
  
  amount[i,1] <- lm1$coefficients[2] 
  amount[i,2] <- lm1$coefficients[2] + selm1*critical.t
  amount[i,3] <- lm1$coefficients[2] - selm1*critical.t
  
  lm2 <- lm(collection ~ post_non, data = d2)
  
  selm2 <- coeftest(lm2, vcov = vcovHC(lm2, type = "HC1"))[2,2]
  critical.t <- abs(qt(p = 0.05, df = lm2$df.residual))
  
  collection[i,1] <- lm2$coefficients[2] 
  collection[i,2] <- lm2$coefficients[2] + selm2*critical.t
  collection[i,3] <- lm2$coefficients[2] - selm2*critical.t
  
  lm3 <- lm(delivery ~ post_non, data = d2)
  
  selm3 <- coeftest(lm3, vcov = vcovHC(lm3, type = "HC1"))[2,2]
  critical.t <- abs(qt(p = 0.05, df = lm3$df.residual))
  
  delivery[i,1] <- lm3$coefficients[2] 
  delivery[i,2] <- lm3$coefficients[2] + selm3*critical.t
  delivery[i,3] <- lm3$coefficients[2] - selm3*critical.t
  
}

# make plots

png(file="out/figure5b.png")
par(mfrow = c(1,3), mar = c(5,3,4,1))

plot(y = amount[,1],
     x = window,
     lwd = 3,
     ylim = c(-0.2,1),
     type = "l",
     main = "Duffel bags collected",
     xlab = "Time window (days)",
     ylab = "")
par(new = TRUE)
plot(y = amount[,2],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
par(new = TRUE)
plot(y = amount[,3],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
abline(h = 0, col = "red", lty = 2)

plot(y = collection[,1],
     x = window,
     lwd = 3,
     ylim = c(-0.2,1),
     type = "l",
     main = "P(Episode of kickback)",
     xlab = "Time window (days)",
     ylab = "")
par(new = TRUE)
plot(y = collection[,2],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
par(new = TRUE)
plot(y = collection[,3],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
abline(h = 0, col = "red", lty = 2)

plot(y = delivery[,1],
     x = window,
     type = "l",
     lwd = 3,
     ylim = c(-0.2,1),
     main = "P(Episode of delivery)",
     xlab = "Time window (days)",
     ylab = "")
par(new = TRUE)
plot(y = delivery[,2],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
par(new = TRUE)
plot(y = delivery[,3],
     x = window,
     ylim = c(-0.2,1),
     type = "l",
     lty = 2,
     xlab = "",
     ylab = "",
     axes = FALSE)
abline(h = 0, col = "red", lty = 2)
dev.off()

###################################################################
# Figure 6a: randomization inference (placebo elections on any day)
###################################################################

# Exclude weekends
d$day <- weekdays(d$date)
d$time <- as.numeric(as.Date(d$date))
d <- d[d$day!="Saturday" & d$day!="Sunday", ]

# create vectors to store results
amount.placebos <- c()
collection.placebos <- c()
delivery.placebos <- c()

# set the number of permutations
sims = 250000 # replace for a smaller number for speed, e.g., 10000

# set the seed for replicability
set.seed(123456)

# conduct randomization inference in a for-loop
for(i in 1:sims){
  
  # get five fake elections
  days <- d$time[sample(1:nrow(d), size = 5)]
  
  # compute before and after 14 days
  d1 <- d[abs(d$time-days[1])<14, ]
  d1$before <- ifelse(d1$time-days[1]>0,0,1)
  d2 <- d[abs(d$time-days[2])<14, ]
  d2$before <- ifelse(d2$time-days[2]>0,0,1)
  d3 <- d[abs(d$time-days[3])<14, ]
  d3$before <- ifelse(d3$time-days[3]>0,0,1)
  d4 <- d[abs(d$time-days[4])<14, ]
  d4$before <- ifelse(d4$time-days[4]>0,0,1)
  d5 <- d[abs(d$time-days[5])<14, ]
  d5$before <- ifelse(d5$time-days[5]>0,0,1)
  
  d.placebo <- rbind.data.frame(d1,d2,d3,d4,d5)  
  
  # remove weekends
  d.placebo <- d.placebo[d.placebo$day!="Sunday" & d.placebo$day!="Saturday", ]
  
  #get coefficients
  lm1 <- lm(collected_amount ~ before, data = d.placebo)
  lm2 <- lm(collection ~ before, data = d.placebo) 
  lm3 <- lm(delivery ~ before, data = d.placebo)
  
  amount.placebos[i] <- lm1$coefficients[2]
  collection.placebos[i] <- lm2$coefficients[2]
  delivery.placebos[i] <- lm3$coefficients[2]
  
  print(i)
}

# compute "exact" p-values
p1 <- sum(abs(amount.placebos)>size14days)/sims
p2 <- sum(abs(collection.placebos)>collection14days)/sims
p3 <- sum(abs(delivery.placebos)>delivery14days)/sims


# plot the results

png(file="out/figure6a.png")
par(mfrow = c(1,3))
hist(amount.placebos,
     xlab = "Total daily kickbacks",
     main = "Total kickbacks",
     breaks = 50)
abline(v = size14days, 
       col = "red", 
       lty = 2,
       lwd = 2)
hist(collection.placebos,
     xlab = "Episode of bribe collection",
     main = "Bribe collection",
     breaks = 50)
abline(v = collection14days, 
       col = "red", 
       lty = 2,
       lwd = 2)
hist(delivery.placebos,
     xlab = "Episode of bribe delivery",
     main = "Bribe delivery",
     breaks = 50)
abline(v = delivery14days, 
       col = "red", 
       lty = 2,
       lwd = 2)
dev.off()


###################################################################
# Figure 6b: randomization inference (placebo elections on Sundays)
###################################################################

#load the dataset
d <- read_excel("data/stealing_dataset.xlsx")

# set dates
d$day <- weekdays(d$date)
d$time <- as.numeric(as.Date(d$date))

# create vectors to store results
amount.placebos <- c()
collection.placebos <- c()
delivery.placebos <- c()

# set number of simulations
sims <- 250000 # replace for a smaller number for speed, e.g., 10000

# set seed for replicability
set.seed(123456)

# compute randomization inference p-values using a for-loop
for(i in 1:sims){

  sundays <- d[d$day=="Sunday", ]
  
  # get five fake elections
  days <- sundays$time[sample(1:nrow(sundays), size = 5)]
  
  # compute before and after 14 days
  d1 <- d[abs(d$time-days[1])<14, ]
  d1$before <- ifelse(d1$time-days[1]>0,0,1)
  d2 <- d[abs(d$time-days[2])<14, ]
  d2$before <- ifelse(d2$time-days[2]>0,0,1)
  d3 <- d[abs(d$time-days[3])<14, ]
  d3$before <- ifelse(d3$time-days[3]>0,0,1)
  d4 <- d[abs(d$time-days[4])<14, ]
  d4$before <- ifelse(d4$time-days[4]>0,0,1)
  d5 <- d[abs(d$time-days[5])<14, ]
  d5$before <- ifelse(d5$time-days[5]>0,0,1)
  
  d.placebo <- rbind.data.frame(d1,d2,d3,d4,d5)  
  
  # remove weekends
  d.placebo <- d.placebo[d.placebo$day!="Sunday" & d.placebo$day!="Saturday", ]
  
  #get coefficients
  lm1 <- lm(collected_amount ~ before, data = d.placebo)
  lm2 <- lm(collection ~ before, data = d.placebo) 
  lm3 <- lm(delivery ~ before, data = d.placebo)
  
  amount.placebos[i] <- lm1$coefficients[2]
  collection.placebos[i] <- lm2$coefficients[2]
  delivery.placebos[i] <- lm3$coefficients[2]
  
  print(i)
}


# obtain "exact" p-values
p1 <- sum(abs(amount.placebos)>size14days)/sims
p2 <- sum(abs(collection.placebos)>collection14days)/sims
p3 <- sum(abs(delivery.placebos)>delivery14days)/sims


# plot the results
png(file="out/figure6b.png")
par(mfrow = c(1,3))
hist(amount.placebos,
     xlab = "Total daily kickbacks",
     main = "Total kickbacks",
     breaks = 100)
abline(v = size14days, 
       col = "red", 
       lty = 2,
       lwd = 2)
hist(collection.placebos,
     xlab = "Episode of bribe collection",
     main = "Bribe collection",
     breaks = 100)
abline(v = collection14days, 
       col = "red", 
       lty = 2,
       lwd = 2)
hist(delivery.placebos,
     xlab = "Episode of bribe delivery",
     main = "Bribe delivery",
     breaks = 100)
abline(v = delivery14days, 
       col = "red", 
       lty = 2,
       lwd = 2)
dev.off()


################################
# Figures in the appendix
################################

##################################################
# RANDOMIZATION INFERENCE WITH DIFFERENT WINDOWS #
##################################################
# Exclude weekends
d$day <- weekdays(d$date)
d <- d[d$day!="Saturday" & d$day!="Sunday", ]

# set window
window <- 1:37

# create empty matrices to store results
amount <- matrix(ncol = 3, nrow = 37)
collection <- matrix(ncol = 3, nrow = 37)
delivery <- matrix(ncol = 3, nrow = 37)

# compute regression for different windows using a for-loop
for(i in 3:37){
  d2 <- d[abs(d$electoral_calendar)<i, ]
  
  lm1 <- lm(collected_amount ~ pre_post, data = d2)
  
  selm1 <- coeftest(lm1, vcov = vcovHC(lm1, type = "HC1"))[2,2]
  critical.t <- abs(qt(p = 0.05, df = lm1$df.residual))
  
  amount[i,1] <- lm1$coefficients[2] 
  amount[i,2] <- lm1$coefficients[2] + selm1*critical.t
  amount[i,3] <- lm1$coefficients[2] - selm1*critical.t
  
  lm2 <- lm(collection ~ pre_post, data = d2)
  
  selm2 <- coeftest(lm2, vcov = vcovHC(lm2, type = "HC1"))[2,2]
  critical.t <- abs(qt(p = 0.05, df = lm2$df.residual))
  
  collection[i,1] <- lm2$coefficients[2] 
  collection[i,2] <- lm2$coefficients[2] + selm2*critical.t
  collection[i,3] <- lm2$coefficients[2] - selm2*critical.t
  
  lm3 <- lm(delivery ~ pre_post, data = d2)
  
  selm3 <- coeftest(lm3, vcov = vcovHC(lm3, type = "HC1"))[2,2]
  critical.t <- abs(qt(p = 0.05, df = lm3$df.residual))
  
  delivery[i,1] <- lm3$coefficients[2] 
  delivery[i,2] <- lm3$coefficients[2] + selm3*critical.t
  delivery[i,3] <- lm3$coefficients[2] - selm3*critical.t
  
}

# save coefficients for 1, 2, 3 and 4 week window

size7days <- amount[7,1]
collection7days <- collection[7,1]
delivery7days <- delivery[7,1]

size14days <- amount[14,1]
collection14days <- collection[14,1]
delivery14days <- delivery[14,1]

size21days <- amount[21,1]
collection21days <- collection[21,1]
delivery21days <- delivery[21,1]

size28days <- amount[28,1]
collection28days <- collection[28,1]
delivery28days <- delivery[28,1]



###### 1 week ############

# Import dataset
library(readxl)
d <- read_excel("data/stealing_dataset.xlsx")

# Exclude weekends
d$day <- weekdays(d$date)
d$time <- as.numeric(as.Date(d$date))

d <- d[d$day!="Saturday" & d$day!="Sunday", ]

# create vectors to store results

amount.placebos <- c()
collection.placebos <- c()
delivery.placebos <- c()

sims = 10000

set.seed(123456)
for(i in 1:sims){
  
  # get five fake elections
  days <- d$time[sample(1:nrow(d), size = 5)]
  
  # compute before and after 7 days
  d1 <- d[abs(d$time-days[1])<7, ]
  d1$before <- ifelse(d1$time-days[1]>0,0,1)
  d2 <- d[abs(d$time-days[2])<7, ]
  d2$before <- ifelse(d2$time-days[2]>0,0,1)
  d3 <- d[abs(d$time-days[3])<7, ]
  d3$before <- ifelse(d3$time-days[3]>0,0,1)
  d4 <- d[abs(d$time-days[4])<7, ]
  d4$before <- ifelse(d4$time-days[4]>0,0,1)
  d5 <- d[abs(d$time-days[5])<7, ]
  d5$before <- ifelse(d5$time-days[5]>0,0,1)
  
  d.placebo <- rbind.data.frame(d1,d2,d3,d4,d5)  
  
  # remove weekends
  d.placebo <- d.placebo[d.placebo$day!="Sunday" & d.placebo$day!="Saturday", ]
  
  #get coefficients
  lm1 <- lm(collected_amount ~ before, data = d.placebo)
  lm2 <- lm(collection ~ before, data = d.placebo) 
  lm3 <- lm(delivery ~ before, data = d.placebo)
  
  amount.placebos[i] <- lm1$coefficients[2]
  collection.placebos[i] <- lm2$coefficients[2]
  delivery.placebos[i] <- lm3$coefficients[2]
  
  print(i)
}


# plot the results

png(file="out/appendix_ri7.png")
par(mfrow = c(1,3))

hist(amount.placebos,
     xlab = "Total daily kickbacks",
     main = "Total kickbacks (p = 0.005)",
     breaks = 50)
abline(v = size7days, 
       col = "red", 
       lty = 2,
       lwd = 2)
p1 <- sum(abs(amount.placebos)>size7days)/sims

hist(collection.placebos,
     xlab = "Episode of bribe collection",
     main = "Bribe collection (p = 0.03)",
     breaks = 50)
abline(v = collection7days, 
       col = "red", 
       lty = 2,
       lwd = 2)
p2 <- sum(abs(collection.placebos)>collection7days)/sims


hist(delivery.placebos,
     xlab = "Episode of bribe delivery",
     main = "Bribe delivery (p < 0.001)",
     breaks = 50)
abline(v = delivery7days, 
       col = "red", 
       lty = 2,
       lwd = 2)
p3 <- sum(abs(delivery.placebos)>delivery7days)/sims
dev.off()

######### 2 weeks ##################

# Import dataset
library(readxl)
d <- read_excel("data/stealing_dataset.xlsx")

# Exclude weekends
d$day <- weekdays(d$date)
d$time <- as.numeric(as.Date(d$date))

d <- d[d$day!="Saturday" & d$day!="Sunday", ]

# create vectors to store results

amount.placebos <- c()
collection.placebos <- c()
delivery.placebos <- c()

sims = 10000

set.seed(123456)
for(i in 1:sims){
  
  # get five fake elections
  days <- d$time[sample(1:nrow(d), size = 5)]
  
  # compute before and after 14 days
  d1 <- d[abs(d$time-days[1])<14, ]
  d1$before <- ifelse(d1$time-days[1]>0,0,1)
  d2 <- d[abs(d$time-days[2])<14, ]
  d2$before <- ifelse(d2$time-days[2]>0,0,1)
  d3 <- d[abs(d$time-days[3])<14, ]
  d3$before <- ifelse(d3$time-days[3]>0,0,1)
  d4 <- d[abs(d$time-days[4])<14, ]
  d4$before <- ifelse(d4$time-days[4]>0,0,1)
  d5 <- d[abs(d$time-days[5])<14, ]
  d5$before <- ifelse(d5$time-days[5]>0,0,1)
  
  d.placebo <- rbind.data.frame(d1,d2,d3,d4,d5)  
  
  # remove weekends
  d.placebo <- d.placebo[d.placebo$day!="Sunday" & d.placebo$day!="Saturday", ]
  
  #get coefficients
  lm1 <- lm(collected_amount ~ before, data = d.placebo)
  lm2 <- lm(collection ~ before, data = d.placebo) 
  lm3 <- lm(delivery ~ before, data = d.placebo)
  
  amount.placebos[i] <- lm1$coefficients[2]
  collection.placebos[i] <- lm2$coefficients[2]
  delivery.placebos[i] <- lm3$coefficients[2]
  
  print(i)
}


# plot the results
png(file="out/appendix_ri14.png")
par(mfrow = c(1,3))

hist(amount.placebos,
     xlab = "Total daily kickbacks",
     main = "Total kickbacks (p = 0.022)",
     breaks = 50)
abline(v = size14days, 
       col = "red", 
       lty = 2,
       lwd = 2)
p1 <- sum(abs(amount.placebos)>size14days)/sims

hist(collection.placebos,
     xlab = "Episode of bribe collection",
     main = "Bribe collection (p = 0.128)",
     breaks = 50)
abline(v = collection14days, 
       col = "red", 
       lty = 2,
       lwd = 2)
p2 <- sum(abs(collection.placebos)>collection14days)/sims


hist(delivery.placebos,
     xlab = "Episode of bribe delivery",
     main = "Bribe delivery (p = 0.057)",
     breaks = 50)
abline(v = delivery14days, 
       col = "red", 
       lty = 2,
       lwd = 2)
p3 <- sum(abs(delivery.placebos)>delivery14days)/sims
dev.off()

######### 3 weeks ##################

# Import dataset
library(readxl)
d <- read_excel("data/stealing_dataset.xlsx")

# Exclude weekends
d$day <- weekdays(d$date)
d$time <- as.numeric(as.Date(d$date))

d <- d[d$day!="Saturday" & d$day!="Sunday", ]

# create vectors to store results

amount.placebos <- c()
collection.placebos <- c()
delivery.placebos <- c()

sims = 10000

set.seed(123456)
for(i in 1:sims){
  
  # get five fake elections
  days <- d$time[sample(1:nrow(d), size = 5)]
  
  # compute before and after 21 days
  d1 <- d[abs(d$time-days[1])<21, ]
  d1$before <- ifelse(d1$time-days[1]>0,0,1)
  d2 <- d[abs(d$time-days[2])<21, ]
  d2$before <- ifelse(d2$time-days[2]>0,0,1)
  d3 <- d[abs(d$time-days[3])<21, ]
  d3$before <- ifelse(d3$time-days[3]>0,0,1)
  d4 <- d[abs(d$time-days[4])<21, ]
  d4$before <- ifelse(d4$time-days[4]>0,0,1)
  d5 <- d[abs(d$time-days[5])<21, ]
  d5$before <- ifelse(d5$time-days[5]>0,0,1)
  
  d.placebo <- rbind.data.frame(d1,d2,d3,d4,d5)  
  
  # remove weekends
  d.placebo <- d.placebo[d.placebo$day!="Sunday" & d.placebo$day!="Saturday", ]
  
  #get coefficients
  lm1 <- lm(collected_amount ~ before, data = d.placebo)
  lm2 <- lm(collection ~ before, data = d.placebo) 
  lm3 <- lm(delivery ~ before, data = d.placebo)
  
  amount.placebos[i] <- lm1$coefficients[2]
  collection.placebos[i] <- lm2$coefficients[2]
  delivery.placebos[i] <- lm3$coefficients[2]
  
  print(i)
}


# plot the results
png(file="out/appendix_ri21.png")
par(mfrow = c(1,3))

hist(amount.placebos,
     xlab = "Total daily kickbacks",
     main = "Total kickbacks (p = 0.025)",
     breaks = 50)
abline(v = size21days, 
       col = "red", 
       lty = 2,
       lwd = 2)
p1 <- sum(abs(amount.placebos)>size21days)/sims

hist(collection.placebos,
     xlab = "Episode of bribe collection",
     main = "Bribe collection (p = 0.115)",
     breaks = 50)
abline(v = collection21days, 
       col = "red", 
       lty = 2,
       lwd = 2)
p2 <- sum(abs(collection.placebos)>collection21days)/sims


hist(delivery.placebos,
     xlab = "Episode of bribe delivery",
     main = "Bribe delivery (p = 0.335)",
     breaks = 50)
abline(v = delivery21days, 
       col = "red", 
       lty = 2,
       lwd = 2)
p3 <- sum(abs(delivery.placebos)>delivery21days)/sims
dev.off()


######### 4 weeks ##################

# Import dataset
library(readxl)
d <- read_excel("data/stealing_dataset.xlsx")

# Exclude weekends
d$day <- weekdays(d$date)
d$time <- as.numeric(as.Date(d$date))

d <- d[d$day!="Saturday" & d$day!="Sunday", ]

# create vectors to store results

amount.placebos <- c()
collection.placebos <- c()
delivery.placebos <- c()

sims = 10000

set.seed(123456)
for(i in 1:sims){
  
  # get five fake elections
  days <- d$time[sample(1:nrow(d), size = 5)]
  
  # compute before and after 28 days
  d1 <- d[abs(d$time-days[1])<28, ]
  d1$before <- ifelse(d1$time-days[1]>0,0,1)
  d2 <- d[abs(d$time-days[2])<28, ]
  d2$before <- ifelse(d2$time-days[2]>0,0,1)
  d3 <- d[abs(d$time-days[3])<28, ]
  d3$before <- ifelse(d3$time-days[3]>0,0,1)
  d4 <- d[abs(d$time-days[4])<28, ]
  d4$before <- ifelse(d4$time-days[4]>0,0,1)
  d5 <- d[abs(d$time-days[5])<28, ]
  d5$before <- ifelse(d5$time-days[5]>0,0,1)
  
  d.placebo <- rbind.data.frame(d1,d2,d3,d4,d5)  
  
  # remove weekends
  d.placebo <- d.placebo[d.placebo$day!="Sunday" & d.placebo$day!="Saturday", ]
  
  #get coefficients
  lm1 <- lm(collected_amount ~ before, data = d.placebo)
  lm2 <- lm(collection ~ before, data = d.placebo) 
  lm3 <- lm(delivery ~ before, data = d.placebo)
  
  amount.placebos[i] <- lm1$coefficients[2]
  collection.placebos[i] <- lm2$coefficients[2]
  delivery.placebos[i] <- lm3$coefficients[2]
  
  print(i)
}


# plot the results
png(file="out/appendix_ri28.png")
par(mfrow = c(1,3))

hist(amount.placebos,
     xlab = "Total daily kickbacks",
     main = "Total kickbacks (p = 0.062)",
     breaks = 50)
abline(v = size28days, 
       col = "red", 
       lty = 2,
       lwd = 2)
p1 <- sum(abs(amount.placebos)>size28days)/sims

hist(collection.placebos,
     xlab = "Episode of bribe collection",
     main = "Bribe collection (p = 0.168)",
     breaks = 50)
abline(v = collection28days, 
       col = "red", 
       lty = 2,
       lwd = 2)
p2 <- sum(abs(collection.placebos)>collection28days)/sims


hist(delivery.placebos,
     xlab = "Episode of bribe delivery",
     main = "Bribe delivery (p = 1.00)",
     breaks = 50)
abline(v = delivery28days, 
       col = "red", 
       lty = 2,
       lwd = 2)
p3 <- sum(abs(delivery.placebos)>delivery28days)/sims
dev.off()
